<?php
// Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
if (getenv('PLESK_INSTALLER_DEBUG') != FALSE) {
    define('DEBUG', true);
}

function printr($str)
{
    echo $str . "\n";
}

function dbg_printr($str)
{
    if (DEBUG === true) {
        printr('D:' . $str);
    }
}

function usage()
{
    printf("Usage: %s <webusers|subdomains>\n", $_SERVER["argv"][0]);
}

function fix_webuser_perms($home) {
    dbg_printr("---> fix webuser perms " . $home);
    @chgrp($home, "psaserv");
}

function fix_subdomain_perms($home) {
    dbg_printr("---> fix subdomain perms " . $home);
    foreach (array("/httpsdocs", "/httpdocs", "/cgi-bin") as $entry) {
        @chgrp($home . $entry, "psaserv");
    }
}

/*
 * Crontab file handling
 */

class Crontab
{
    private $_crontab = array();
    private $_user;
    private $_re_comment = '/^#(\s|\n).*$/';
    static $_comment_prefix = '##';

    public function __construct($user)
    {
        $this->_user = $user;
        $this->_read();
    }

    public function is_empty()
    {
        return empty($this->_crontab);
    }

    public function clear()
    {
        $this->_crontab = array();
        exec("crontab -u $this->_user -r");
    }

    private function _read()
    {
        exec("crontab -u $this->_user -l", $crons, $rc);
        foreach ($crons as $line) {
            $line = trim($line);
            if (preg_match($this->_re_comment, $line)) { // skip top comments
                continue;
            }

            if (!$line) { // skip empty
                continue;
            }
            $this->_crontab[] = $line;
        }
    }

    static function _comment(&$item, $index)
    {
        if ($item[0] == "#") {
            return;
        }

        $item = self::$_comment_prefix . "\t$item";
    }

    public function comment()
    {
         array_walk($this->_crontab, array("Crontab", "_comment"));
    }

    public function save()
    {
        $filename = tempnam("/tmp", "cron");
        $file = fopen($filename, "w");
        foreach ($this->_crontab as $line) {
            fwrite($file, $line."\n");
        }
        fclose($file);

        exec("crontab -u $this->_user $filename", $returnar, $return);
        if ($return != 0) {
            echo "Error updating crontab ($return) for user ($this->_user)\n";
            unlink($filename);
            return false;
        }

        unlink($filename);
        return true;
    }

    public function export()
    {
        return $this->_crontab;
    }

    public function add($entry)
    {
        if (is_array($entry)) {
            $this->_crontab = array_merge($this->_crontab, $entry);
        } else {
            $this->_crontab[] = $entry;
        }
    }

    public function __toString()
    {
        return join("\n", $this->_crontab);
    }
}

// poor man option parser
if ($_SERVER["argc"] != 2) {
    fprintf(STDERR, "Wrong number of args specified\n");
    usage();
    exit(1);
}

switch($_SERVER["argv"][1]) {
    case "webusers":
        $command = "webusers";
        $query = "SELECT web_users.dom_id, su_domains.login, su_web_users.login, su_web_users.id, su_domains.id, su_web_users.home, web_users.id" .
        " FROM web_users" .
        " LEFT JOIN sys_users as su_web_users on web_users.sys_user_id = su_web_users.id" .
        " LEFT JOIN domains ON web_users.dom_id=domains.id" .
        " LEFT JOIN hosting ON domains.id=hosting.dom_id" .
        " LEFT JOIN sys_users AS su_domains ON hosting.sys_user_id=su_domains.id" .
        " WHERE su_web_users.mapped_to IS NULL";
        break;       
    case "subdomains":
        $command = "subdomains";
        $query= "SELECT domains.id, su_domains.login, su_sub.login, su_sub.id, su_domains.id, su_sub.home, subdomains.id" .
        " FROM subdomains" .
        " LEFT JOIN sys_users AS su_sub ON subdomains.sys_user_id=su_sub.id" .
        " LEFT JOIN domains ON subdomains.dom_id=domains.id" . 
        " LEFT JOIN hosting ON domains.id=hosting.dom_id" .
        " LEFT JOIN sys_users AS su_domains ON hosting.sys_user_id=su_domains.id" .
        " WHERE subdomains.sys_user_type='native' AND su_sub.mapped_to IS NULL";
        break;
    default:
		printr("Invalid command specified: " . $_SERVER["argv"][1]);
        usage();
        exit(1);
}

$password = file_get_contents('/etc/psa/.psa.shadow');
$password = chop($password);
$link = mysql_connect('localhost', 'admin', $password);
if (!$link) {
    printr('Unable connect to the Plesk database: ' . mysql_error());
    exit(1);
}
if (!mysql_select_db('psa', $link)) {
    printr('Unable to select database psa: ' . mysql_error($link));
    exit(1);
}

$rc = 0;
mysql_query('SET NAMES "binary"');

$res = mysql_query($query);
if (!$res) {
    printr('Cannot query sys users to convert: ' . mysql_error($link));
	dbg_printr('Query was: ' . $query);
    exit(1);
}

while(($row = mysql_fetch_row($res))) {
    $db_domain_id = $row[0];
    $domain_ftp_login = $row[1];
    $old_sysuser_login = $row[2];
    $db_old_sysuser_id = $row[3];
    $db_domain_sysuser_id = $row[4];
    $homedir = $row[5];
    $id = $row[6];

    dbg_printr(sprintf("--> User '%s'(%d) -> '%s'(%d) on domain (%d)", $old_sysuser_login, $db_old_sysuser_id, $domain_ftp_login, $db_domain_sysuser_id, $db_domain_id));

    if ($command  == "subdomains") {
// Add user to ftp users table, only for subdomains
        $query = sprintf('REPLACE INTO ftp_users (dom_id, sys_user_id) VALUES (%d, %d)', $db_domain_id, $db_old_sysuser_id);
        if (!mysql_query($query)) {
            printr('Cannot update ftp_users table: ' . mysql_error($link));
            $rc = 1;
            continue;
        }
    }

    $userinfo = posix_getpwnam($domain_ftp_login);
    if ($userinfo == false) {
        printr('Cannot get id for domain user: ' . $domain_ftp_login);
        $rc = 1;
        continue;
    }

    if (@is_executable("/usr/sbin/pw")) {
// On linux homedir entries are chowned to new id. We should check it on FreeBSD
        $cmd = sprintf("/usr/sbin/pw usermod %s -u %d", escapeshellarg($old_sysuser_login), $userinfo["uid"]);
    } elseif (@is_executable("/usr/sbin/usermod")){
        $cmd = sprintf("/usr/sbin/usermod -u %d -o %s", $userinfo["uid"], escapeshellarg($old_sysuser_login));
    } else {
        die("Cannot found usermod engine\n");
    }

// Call for usermod
    system($cmd, $retval);
    if($retval != 0) {
        printr('Cannot map ' . escapeshellarg($old_sysuser_login) . ' to ' . escapeshellarg($domain_ftp_login));
		dbg_printr('Command was: ' . $cmd);
        $rc = 1;
        continue;
    }

// On SuSE permission corrupted after usermod call
    if ($command  == "subdomains") {
        fix_subdomain_perms($homedir);
    } elseif ($command == "webusers") {
        fix_webuser_perms($homedir);
    }


// Fixup sys user table
    $query = sprintf('UPDATE sys_users SET mapped_to=%d WHERE id=%d', $db_domain_sysuser_id, $db_old_sysuser_id);
    if (!mysql_query($query)) {
        printr('Cannot update sys_users table: ' . mysql_error($link));
        $rc = 1;
        continue;
    }

// Migrate crontab from subdomain and web users to domain user
	$crontab_su = new Crontab($old_sysuser_login);
	if (! $crontab_su->is_empty()) {
		dbg_printr("--> migrate crontab for " . $old_sysuser_login . " -> " .  $domain_ftp_login);
		$crontab_domain = new Crontab($domain_ftp_login);
		$crontab_su->comment();
		$crontab_domain->add($crontab_su->export());
		if (! $crontab_domain->save()) {
			printr("Cannot migrate crontab for " . $old_sysuser_login . " -> " . $domain_ftp_login);
			$rc = 1;
			continue;
		} else {
			$crontab_su->clear();
		}
	}
    if ($command == "subdomains") {
// Now subdomain has 'main' in sysuser type for idempotency
        $query = sprintf("UPDATE subdomains SET sys_user_id=%d, sys_user_type='main' WHERE id=%d", $db_domain_sysuser_id, $id);
        if (!mysql_query($query)) {
            printr('Cannot set  subdomain sys_user to main domain sys_user: ' . mysql_error($link));
            $rc = 1;
            continue;
        }
    }
	dbg_printr("---> Done with " . $old_sysuser_login);
}
exit($rc);
?>
