-- Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
-- Service Nodes
CREATE TABLE IF NOT EXISTS ServiceNodes (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `name` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `transport` enum('local', 'remote') NOT NULL,
  `remoteIpAddress` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `accessKey` TEXT CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `externalId` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',
  UNIQUE (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceNodeProperties (
  `serviceNodeId` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `value` BLOB NOT NULL,
  PRIMARY KEY (`serviceNodeId`, `name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `ServiceNodeCertificates` (
  `serviceNodeId` int unsigned NOT NULL,
  `certificateId` int unsigned NOT NULL,
  `certFile` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',
  `caFile` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',
  PRIMARY KEY  (`serviceNodeId`,`certificateId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceNodeCache (
  `serviceNodeId` INT UNSIGNED NOT NULL,
  `pathId` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` TEXT CHARACTER SET ascii COLLATE ascii_bin,
  `cache` TEXT CHARACTER SET ascii COLLATE ascii_bin,
  PRIMARY KEY (`serviceNodeId`, `pathId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- DNS Resource Records
CREATE TABLE IF NOT EXISTS dns_refs (
  `uid`             VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin PRIMARY KEY,
  zoneId            INT UNSIGNED NOT NULL,
  zoneRecordId      INT UNSIGNED DEFAULT NULL,
  templateRecordId  INT UNSIGNED DEFAULT NULL,
  status            enum('syn', 'mod', 'del') NOT NULL DEFAULT 'syn',
                    INDEX (`zoneId`),
                    INDEX (`zoneRecordId`),
                    INDEX (`templateRecordId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS PhpSettings (
  `id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
  `noteId` INT UNSIGNED DEFAULT 0
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS PhpSettingsParameters (
  `id` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `value` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
  PRIMARY KEY (`id`, `name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- Site related actions
replace into actions(name, descr, enabled) values ('site_create', 'Create additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_update', 'Update additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_delete', 'Delete additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_status_update', 'Change status of additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_dns_update', 'Update additional domain DNS zone status', 'true');
replace into actions(name, descr, enabled) values ('site_guid_update', 'Change site guid', 'true');

replace into actions(name, descr, enabled) values ('site_alias_create', 'Create alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_update', 'Update alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_delete', 'Delete alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_dns_update', 'Update DNS zone for alias for additional domain', 'true');

replace into actions(name, descr, enabled) values ('site_subdomain_create', 'Create subdomain for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_update', 'Update subdomain for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_delete', 'Delete subdomain for additional domain', 'true');

replace into actions(name, descr, enabled) values ('subdomain_dns_update', 'Update subdomain DNS zone status', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_dns_update', 'Update DNS zone of subdomain for additional domain status', 'true');

-- Rename 'manage_php_safe_mode' permission to 'manage_php_settings'
update Permissions set `permission` = 'manage_php_settings' where `permission` = 'manage_php_safe_mode';
update TmplData set `element` = 'manage_php_settings' where `element`='manage_php_safe_mode';

-- Enforce to show EULA
delete from misc where param = 'not_showLicense';

-- Table for API statistic collection
CREATE TABLE IF NOT EXISTS `ApiRpcCallsStat` (
  `id` int(10) unsigned NOT NULL auto_increment PRIMARY KEY,
  `Version` varchar(7) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Operator` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Command` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Session` varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '0',
  `FilterName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '0',
  `GroupOperation` int(10) NOT NULL default '0',
  `LastExecutionDate` datetime NOT NULL default '0000-00-00 00:00:00',
  `Count` int(10) unsigned NOT NULL default '0',
  UNIQUE KEY `LogItem` (`Version`,`Operator`,`Command`,`Session`,`FilterName`,`GroupOperation`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
