-- Core services tables

CREATE TABLE IF NOT EXISTS ServiceInstallations (
    `id`                    INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
    `name`                  VARCHAR(255) NOT NULL,
    `status`                INT UNSIGNED NOT NULL DEFAULT 0,
    `serviceNodeId`         INT UNSIGNED NOT NULL,
                            UNIQUE (`name`, `serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceInstallationProperties (
    `serviceInstallationId`  INT UNSIGNED NOT NULL,
    `name`                   VARCHAR(255) NOT NULL,
    `value`                  TEXT,
                             PRIMARY KEY (`serviceInstallationId`, `name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS PlanServiceInstallations (
    `id`                    INT UNSIGNED AUTO_INCREMENT,
    `planId`                INT UNSIGNED NOT NULL,
    `serviceInstallationId` INT UNSIGNED NOT NULL,
    `assigned`              INT UNSIGNED NOT NULL DEFAULT 1,
                            PRIMARY KEY (`id`, `planId`, `serviceInstallationId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS PlanServiceProperties (
    `planServiceId`         INT UNSIGNED NOT NULL,
    `name`                  VARCHAR(255) NOT NULL,
    `value`                 TEXT,
                            PRIMARY KEY (`planServiceId`, `name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceInstanceProperties (
    `serviceInstanceId`      INT UNSIGNED NOT NULL,
    `name`                   VARCHAR(255) NOT NULL,
    `value`                  TEXT,
                             PRIMARY KEY (`serviceInstanceId`, `name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceInstanceResources (
    `serviceInstanceId`      INT UNSIGNED NOT NULL,
    `serviceResourceType`    VARCHAR(255) NOT NULL,
    `serviceResourceId`      INT UNSIGNED NOT NULL,
    `reference`              VARCHAR(255) NOT NULL,
                             PRIMARY KEY (`serviceInstanceId`, `serviceResourceType`, `serviceResourceId`, `reference`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceLimits (
    `limitName`             VARCHAR(255) NOT NULL,
    `serviceName`           VARCHAR(255) NOT NULL,
                            PRIMARY KEY (`limitName`, `serviceName`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServicePermissions (
    `permissionName`        VARCHAR(255) NOT NULL,
    `serviceName`           VARCHAR(255) NOT NULL,
                            PRIMARY KEY (`permissionName`, `serviceName`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceInstances (
  `id`                      INT UNSIGNED PRIMARY KEY AUTO_INCREMENT,
  `serviceInstallationId`   INT UNSIGNED NOT NULL,
  `servicePackageId`        INT UNSIGNED NOT NULL,
  `reference`               VARCHAR(255),
  `status`                  INT UNSIGNED NOT NULL DEFAULT 1,
  `enabled`                 INT UNSIGNED NOT NULL DEFAULT 1,
                            UNIQUE KEY(`serviceInstallationId`, `servicePackageId`, `reference`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS ServiceInstanceDepends (
  `serviceInstanceId`       INT UNSIGNED NOT NULL,
  `requiredInstanceId`      INT UNSIGNED NOT NULL,
  `apiType`                 VARCHAR(255),
                            PRIMARY KEY(`serviceInstanceId`, `requiredInstanceId`, `apiType`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
