-- Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
--
-- To prevent failure during upgrade from 11.0.
--
CREATE TABLE IF NOT EXISTS `admin_aliases` (
    id                      INT UNSIGNED AUTO_INCREMENT,
    login                   VARCHAR(20) NOT NULL DEFAULT '',
    account_id              INT(10) UNSIGNED NOT NULL DEFAULT '0',
    arealname               VARCHAR(255) NOT NULL DEFAULT '',
    aemail                  VARCHAR(255) NOT NULL DEFAULT '',
    comments                VARCHAR(255) NOT NULL DEFAULT '',
    status                  BIGINT UNSIGNED NOT NULL default '0',
                            PRIMARY KEY  (id),
                            UNIQUE KEY login (login)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `admin_aliases_param` (
    alias_id                INT(10) UNSIGNED NOT NULL DEFAULT '0',
    param                   VARCHAR(245) NOT NULL DEFAULT '',
    val                     VARCHAR(255) DEFAULT NULL,
                            PRIMARY KEY (alias_id, param)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `dsn` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `dom_id` int(10) unsigned default NULL,
  `serviceNodeId` int(10) unsigned NOT NULL default 1,
  `name` varchar(255) NOT NULL default '',
  `driver` varchar(255) NOT NULL default '',
  `description` varchar(255) default NULL,
  `configured` enum('false','true') NOT NULL default 'false',
  `cstring` text,
  PRIMARY KEY  (`id`),
  UNIQUE KEY `name` (`name`,`serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `cf_dsn` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `domain_id` int(10) unsigned NOT NULL default '0',
  `dsn_name` varchar(64) NOT NULL default '',
  `driver_name` varchar(255) NOT NULL default '',
  `description` varchar(255) default NULL,
  `is_valid` enum('false','true') NOT NULL default 'false',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `dsn_name` (`domain_id`,`dsn_name`),
  KEY `domain_id` (`domain_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `cf_dsn_params` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `cf_dsn_id` int(10) unsigned NOT NULL default '0',
  `name` varchar(64) NOT NULL default '',
  `value` varchar(255) default NULL,
  PRIMARY KEY  (`id`),
  KEY `dsn_id` (`cf_dsn_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `fpse_users` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `dom_id` int(10) unsigned NOT NULL default '0',
  `sys_user_id` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `sys_user_id` (`sys_user_id`),
  KEY `dom_id` (`dom_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `hotlink_prot` (
  `dom_id` int(10) unsigned NOT NULL PRIMARY KEY,
  `enabled` enum('false','true') NOT NULL default 'false',
  `extensions` varchar(255) NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `hotlink_friends` (
  `id` int(10) unsigned NOT NULL auto_increment PRIMARY KEY,
  `dom_id` int(10) unsigned NOT NULL,
  `friend_dom` varchar(255) NOT NULL,
  INDEX (dom_id)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `stat` (
  `dom_id` int(10) unsigned NOT NULL default '0',
  `date` date NOT NULL default '0000-00-00',
  `transfer` bigint(20) unsigned default NULL,
  PRIMARY KEY  (`dom_id`,`date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `wsb_param` (
  `dom_id` int(10) unsigned NOT NULL default '0',
  `dom_type` enum('domain','subdomain') NOT NULL default 'domain',
  `param` varchar(245) NOT NULL default '',
  `val` varchar(255) default NULL,
  PRIMARY KEY  (`dom_id`,`dom_type`,`param`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `IisAppPoolDomains` (
  `domainId` int(10) unsigned NOT NULL default '0',
  `poolId` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`domainId`),
  KEY `poolId` (`poolId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `IisAppPools` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `serviceNodeId` int(10) unsigned NOT NULL default '1',
  `ownerType` enum('client','domain') NOT NULL default 'client',
  `ownerId` int(10) unsigned NOT NULL default '0',
  `identity` varchar(20) NOT NULL,
  `isStarted` int(11) NOT NULL default '1',
  `cpuLimit` int(11) NOT NULL default '-1',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `ownerId` (`serviceNodeId`,`ownerType`,`ownerId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `IisAppPoolsPolicy` (
  `serviceNodeId` int(10) unsigned NOT NULL default '1',
  `mode` enum('shared','dedicated','mixed') NOT NULL default 'mixed',
  PRIMARY KEY  (`serviceNodeId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `SharedSslDomains` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `serviceNodeId` int(10) unsigned NOT NULL default '1',
  `clientId` int(10) unsigned NOT NULL default '0',
  `domainId` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `domainId` (`serviceNodeId`,`clientId`,`domainId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE IF NOT EXISTS `shared_ssl_links` (
  `id` int(10) unsigned NOT NULL auto_increment,
  `sharedSslId` int(10) unsigned NOT NULL default '0',
  `name` varchar(255) NOT NULL default '',
  `require_ssl` enum('false','true') NOT NULL default 'false',
  `dom_id` int(10) unsigned NOT NULL default '0',
  `dom_type` enum('domain','subdomain') NOT NULL default 'domain',
  `target` varchar(255) NOT NULL default 'httpdocs',
  PRIMARY KEY  (`id`),
  UNIQUE KEY `dom_id` (`dom_id`,`dom_type`),
  UNIQUE KEY `name` (`name`),
  KEY `sharedSslId` (`sharedSslId`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- daily antivirus statistics
CREATE TABLE IF NOT EXISTS `avstatistics` (
  `id`    INT UNSIGNED NOT NULL AUTO_INCREMENT,
  PRIMARY KEY (id),
  `type`  ENUM('summary','viruses','recipients','spam_summary', 'spam_recipients') NOT NULL DEFAULT "summary",
  `date`  DATE NOT NULL DEFAULT "0000-00-00",
  UNIQUE (`type`, `date`),
  `name`  VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `val`   BIGINT UNSIGNED NOT NULL DEFAULT 0
);

-- mail server properties table
CREATE TABLE IF NOT EXISTS `MailServerProperties` (
  `serviceNodeId` INT UNSIGNED NOT NULL,
                              -- service node, where system user was created
  `name` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL,
                              -- mail server peoperty name
  `value` VARCHAR(2000) CHARACTER SET binary NOT NULL,
                              -- mail server peoperty value
  UNIQUE (serviceNodeId, name)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


replace into actions(name, descr, enabled) values ('remote_dns_status_update', 'Update remote DNS server status', 'false');
replace into actions(name, descr, enabled) values ('admin_alias_create', 'Create administrator subaccount', 'false');
replace into actions(name, descr, enabled) values ('admin_alias_update', 'Update administrator subaccount', 'false');
replace into actions(name, descr, enabled) values ('admin_alias_delete', 'Delete administrator subaccount', 'false');


