<?php
// Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
/**
 * Utility for performing initial setup and upgrade of database
 *
 * @package Smb_Application
 */
class DbManager
{

    /**
     * Run application
     *
     */
    public function run()
    {
        $this->_setupDbConnection();
        $migration = new SmbMigration(SMB_UPGRADE_DB_PATH);

        $from = $migration->getCurrentVersion();
        $last = $migration->getLatestVersion();

        if (isset($GLOBALS['argv'][1])) {
            $to = $GLOBALS['argv'][1];
        } else {
            $to = $last;
        }

        if ($from == $to) {
            echo "Database is up-to-date\n";
            exit(0);
        }

        if ($to > $last) {
            $this->_fatalError("Version $to is unknown (greater than $last).");
        }

        echo "Performing migration from $from to $to\n";

        $version = $migration->migrate($to);

        echo "Database upgraded to version $version\n";
    }

    /**
     * Setup DB connection for Doctrine
     *
     */
    private function _setupDbConnection()
    {
        $username = 'admin';
        $host = 'localhost';
        $dbname = 'psa';
        $password = urlencode(trim(@file_get_contents('/etc/psa/.psa.shadow')));

        $dsn = "mysql://{$username}:{$password}@{$host}/{$dbname}";

        $connection = Doctrine_Manager::connection($dsn);
        $connection->setAttribute(Doctrine::ATTR_QUOTE_IDENTIFIER, true);
    }

    /**
     * Raise fatal error
     *
     * @param string $message
     */
    protected function _fatalError($message)
    {
        echo $message . PHP_EOL;
        exit(1);
    }
}