<?php
// Copyright 1999-2014. Parallels IP Holdings GmbH. All Rights Reserved.
/**
 * Database migration step
 *
 * @package Smb_Migration
 */
class SmbMigrationStep extends Doctrine_Migration
{

    protected $_fieldPrimaryKey = array(
        'type' => 'integer',
        'primary' => true,
        'length' => 4,
        'autoincrement' => true,
        'notnull' => true,
    );

    protected $_fieldString = array(
        'type' => 'string',
        'length' => 255,
    );

    protected $_fieldText = array(
        'type' => 'string',
        'length' => 64000,
    );

    protected $_fieldInteger = array(
        'type' => 'integer',
        'length' => 4,
    );

    protected $_fieldUuid = array(
        'type' => 'string',
        'notnull' => true,
        'length' => 36,
        'unique' => true,
    );

    protected $_fieldBoolean = array(
        'type' => 'integer',
        'length' => 4,
    );

    protected $_fieldDate = array(
        'type' => 'string',
        'length' => 25,
        'notnull' => true,
    );

    protected $_fieldReference = array(
        'type' => 'integer',
        'length' => 4,
        'notnull' => true,
    );

    protected $_tableDefaultOptions = array(
        'collate' => 'utf8_general_ci',
        'character_set' => 'utf8',
        'type' => 'innodb',
    );

    /**
     * Get simple index structure
     *
     * @param string $fieldName
     * @return array
     */
    protected function _getSimpleIndex($fieldName)
    {
        return array('fields' => array($fieldName => array()));
    }

    /**
     * Insert data into table (data as non-associative array)
     *
     * @param string $tableName
     * @param array $data
     */
    protected function _insert($tableName, array $data)
    {
        $placeholders = array_fill(1, count($data), '?');

        $connection = Doctrine_Manager::connection();
        $query = 'INSERT INTO ' . $connection->quoteIdentifier($tableName)
            . ' VALUES (' . implode(', ', $placeholders) . ')';

        return $connection->exec($query, array_values($data));
    }

    /**
     * Update data in the table
     * @param string $tableName
     * @param array $fields
     * @param array $identifier
     */
    protected function _update($tableName, array $fields, array $identifier)
    {
        $connection = Doctrine_Manager::connection();

        $table = new Doctrine_Table($tableName, $connection);
        $table->initIdentifier();

        return $connection->update($table, $fields, $identifier);
    }

    /**
     * Returns date string suitable for DB
     *
     * @param int|null $timestamp
     * @return string
     */
    protected static function _timestampToDbString($timestamp = null)
    {
        return (is_null($timestamp))
            ? date(DATE_ATOM)
            : date(DATE_ATOM, $timestamp);
    }

    /**
     * Generate UUID
     *
     * @return string
     * @see http://en.wikipedia.org/wiki/UUID
     */
    protected static function _getUuid()
    {
        $hash = self::_getHash();

        return substr($hash, 0, 8) . '-' . substr($hash, 8, 4) . '-'
            . substr($hash, 12, 4). '-' . substr($hash, 16, 4). '-' . substr($hash, 20);
    }

    /**
     * Generate hash
     *
     * @return string
     * @see http://php.net/uniqid
     */
    protected static function _getHash()
    {
        return md5(uniqid(rand(), true));
    }
}